"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var fs = _interopRequireWildcard(require("fs"));

var _fsExtra = _interopRequireDefault(require("fs-extra"));

var _path = _interopRequireDefault(require("path"));

var _webpack = _interopRequireDefault(require("webpack"));

var _getLog = require("./get-log");

var _get_webpack_configs = _interopRequireDefault(require("./get_webpack_configs"));

var _write_package_jsons_for_assemblies = _interopRequireDefault(require("./write_package_jsons_for_assemblies"));

var _get_peer_dependencies = _interopRequireDefault(require("./get_peer_dependencies"));

var _show_build_info = _interopRequireDefault(require("./show_build_info"));

var _copy_env_to_dist = _interopRequireDefault(require("./copy_env_to_dist"));

var _validate_config = _interopRequireDefault(require("./validate_config"));

var _detect_errors = _interopRequireDefault(require("./detect_errors"));

var _adjustResolveConfig = _interopRequireDefault(require("./adjust-resolve-config"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const log = (0, _getLog.getLog)('build');

const buildMode = async (resolveConfig, adjustWebpackConfigs) => {
  log.debug('Starting "build" mode');
  await (0, _adjustResolveConfig.default)(resolveConfig);
  (0, _validate_config.default)(resolveConfig);

  _fsExtra.default.copySync(_path.default.resolve(process.cwd(), resolveConfig.staticDir), _path.default.resolve(process.cwd(), resolveConfig.distDir, './client'));

  const nodeModulesByAssembly = new Map();
  const webpackConfigs = await (0, _get_webpack_configs.default)({
    resolveConfig,
    nodeModulesByAssembly,
    adjustWebpackConfigs
  });
  const peerDependencies = (0, _get_peer_dependencies.default)();
  const compiler = (0, _webpack.default)(webpackConfigs);
  await new Promise((resolve, reject) => {
    compiler.run((err, {
      stats
    }) => {
      console.log(' '); // eslint-disable-line no-console

      stats.forEach(_show_build_info.default.bind(null, err));
      (0, _write_package_jsons_for_assemblies.default)(resolveConfig.distDir, nodeModulesByAssembly, peerDependencies);
      (0, _copy_env_to_dist.default)(resolveConfig.distDir);
      const hasNoErrors = (0, _detect_errors.default)(stats, false);

      if (hasNoErrors) {
        resolve();
        log.debug('Building complete');
      } else {
        reject(stats.toString(''));
      }
    });
  });

  const npmRc = _path.default.resolve(process.cwd(), '.npmrc');

  if (fs.existsSync(npmRc)) {
    fs.copyFileSync(npmRc, _path.default.resolve(process.cwd(), resolveConfig.distDir, `./common/${resolveConfig.target}-entry/.npmrc`));
  }
};

var _default = buildMode;
exports.default = _default;
//# sourceMappingURL=build_mode.js.map