"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "checkRuntimeEnv", {
  enumerable: true,
  get: function () {
    return _core.checkRuntimeEnv;
  }
});
Object.defineProperty(exports, "declareRuntimeEnv", {
  enumerable: true,
  get: function () {
    return _core.declareRuntimeEnv;
  }
});
exports.injectRuntimeEnv = exports.default = void 0;
Object.defineProperty(exports, "runtimeEnvSymbol", {
  enumerable: true,
  get: function () {
    return _core.runtimeEnvSymbol;
  }
});

var _crypto = _interopRequireDefault(require("crypto"));

var _core = require("@resolve-js/core");

var _client_global_object = _interopRequireDefault(require("./client_global_object"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const createDigestHash = (prefix, content) => {
  const hmac = _crypto.default.createHmac('sha512', prefix);

  hmac.update(content);
  return hmac.digest('hex');
};

const injectRuntimeEnv = (json, isClient = false) => {
  const seedPrefix = JSON.stringify(json);
  const runtimeDigestBegin = createDigestHash('digest-begin', seedPrefix);
  const runtimeDigestEnd = createDigestHash('digest-end', seedPrefix);
  const envObj = isClient ? (0, _client_global_object.default)('__RESOLVE_RUNTIME_ENV__') : 'process.env';
  const rawResult = JSON.stringify(json, (key, value) => {
    if ((0, _core.checkRuntimeEnv)(value)) {
      return `${runtimeDigestBegin}${JSON.stringify({
        envName: String(value),
        defaultValue: value.defaultValue
      })}${runtimeDigestEnd}`;
    }

    return value;
  }, 2);
  const runtimeEnvRegex = new RegExp(`"${runtimeDigestBegin}((?:.|\\n)*?)${runtimeDigestEnd}"`, 'ig');
  const result = rawResult.replace(runtimeEnvRegex, (match, group) => {
    const {
      envName,
      defaultValue
    } = JSON.parse(JSON.parse(`"${group}"`));
    const first = `${envObj}[${JSON.stringify(envName)}]`;
    const second = JSON.stringify(defaultValue);
    const choice = `(first, second) => (first != null ? first : second)`;
    return `((${choice})(${first}, ${second}))`;
  });
  return result;
};

exports.injectRuntimeEnv = injectRuntimeEnv;
var _default = _core.declareRuntimeEnv;
exports.default = _default;
//# sourceMappingURL=declare_runtime_env.js.map