"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _path = _interopRequireDefault(require("path"));

var _esmWebpackPlugin = _interopRequireDefault(require("@purtuga/esm-webpack-plugin"));

var _attach_webpack_configs_client_entries = _interopRequireDefault(require("./attach_webpack_configs_client_entries"));

var _get_modules_dirs = _interopRequireDefault(require("./get_modules_dirs"));

var _constants = require("./constants");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const getClientWebpackConfigs = ({
  resolveConfig,
  alias
}) => {
  const targetMode = resolveConfig.target;

  const distDir = _path.default.resolve(process.cwd(), resolveConfig.distDir);

  const clientTransformBabelOptions = {
    cacheDirectory: true,
    babelrc: false,
    presets: ['@babel/preset-env', '@babel/preset-react'],
    plugins: ['@babel/plugin-proposal-class-properties', '@babel/plugin-proposal-export-default-from', '@babel/plugin-proposal-export-namespace-from', ['@babel/plugin-transform-runtime', {
      corejs: false,
      helpers: true,
      regenerator: true,
      useESModules: false
    }]]
  };

  const getBaseClientConfig = isClient => ({
    name: 'ClientConfigName',
    entry: {},
    context: _path.default.resolve(process.cwd()),
    mode: resolveConfig.mode,
    performance: false,
    devtool: 'source-map',
    target: 'web',
    output: {
      path: distDir,
      filename: '[name]',
      devtoolModuleFilenameTemplate: '[namespace][resource-path]',
      devtoolFallbackModuleFilenameTemplate: '[namespace][resource-path]?[hash]'
    },
    resolve: {
      modules: (0, _get_modules_dirs.default)(),
      alias
    },
    module: {
      rules: [{
        test: Object.values(alias),
        use: [{
          loader: require.resolve('babel-loader'),
          options: clientTransformBabelOptions
        }, {
          loader: require.resolve('./val_query_loader'),
          options: {
            resolveConfig,
            isClient
          }
        }]
      }, {
        test: /\.js$/,
        use: {
          loader: require.resolve('babel-loader'),
          options: {
            cacheDirectory: true
          }
        },
        exclude: [/node_modules/, ...(0, _get_modules_dirs.default)({
          isAbsolutePath: true
        }), _path.default.resolve(__dirname, '../lib'), _path.default.resolve(__dirname, '../es')]
      }, {
        test: /@resolve-js\/runtime[\\/](?!node_modules).*?\.js$/,
        use: {
          loader: require.resolve('babel-loader'),
          options: clientTransformBabelOptions
        }
      }]
    },
    plugins: []
  });

  const getReadModelEntryConfig = name => ({ ...getBaseClientConfig(false),
    name: `${_constants.OPTIONAL_ASSET_PREFIX} Read-model adapter-inline chunk ${name}`,
    entry: {
      [`common/${targetMode}-entry/read-model-${name}.js`]: `${_path.default.resolve(__dirname, './alias/$resolve.readModelProcedure.js')}?readModelName=${name}`
    },
    module: { ...getBaseClientConfig(false).module,
      rules: [{
        test: /\.js$/,
        sideEffects: false,
        use: {
          loader: require.resolve('babel-loader'),
          options: {
            sourceType: 'unambiguous',
            cacheDirectory: false,
            babelrc: false,
            presets: [['@babel/preset-env', {
              loose: true,
              modules: false
            }]],
            plugins: [['@babel/plugin-transform-runtime', {
              corejs: false,
              helpers: true,
              regenerator: true,
              useESModules: false
            }]]
          }
        },
        exclude: [...Object.values(alias), /@babel\/runtime/, /regenerator-runtime/]
      }, ...getBaseClientConfig(false).module.rules]
    },
    optimization: { ...getBaseClientConfig(false).optimization,
      noEmitOnErrors: true
    },
    output: { ...getBaseClientConfig(false).output,
      libraryTarget: 'var',
      library: '__READ_MODEL_ENTRY__'
    },
    plugins: [...getBaseClientConfig(false).plugins],
    mode: 'production',
    devtool: undefined,
    target: 'node'
  });

  const clientConfigs = [{ ...getBaseClientConfig(true),
    name: 'Shared client ESM chunks',
    entry: {
      'common/shared/client-chunk.js': _path.default.resolve(__dirname, './alias/$resolve.clientChunk.js'),
      'common/shared/client-imports.js': _path.default.resolve(__dirname, './alias/$resolve.clientImports.js'),
      'common/shared/view-models.js': _path.default.resolve(__dirname, './alias/$resolve.viewModels.js')
    },
    output: { ...getBaseClientConfig(true).output,
      libraryTarget: 'var',
      library: '__RESOLVE_ENTRY__'
    },
    plugins: [...getBaseClientConfig(true).plugins, new _esmWebpackPlugin.default()]
  }, ...resolveConfig.readModels.map(({
    name
  }) => getReadModelEntryConfig(name))];
  (0, _attach_webpack_configs_client_entries.default)(resolveConfig, getBaseClientConfig(true), clientConfigs, true);
  return clientConfigs;
};

var _default = getClientWebpackConfigs;
exports.default = _default;
//# sourceMappingURL=get_webpack_client_configs.js.map