"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _path = _interopRequireDefault(require("path"));

var _esmWebpackPlugin = _interopRequireDefault(require("@purtuga/esm-webpack-plugin"));

var _webpackNodeExternals = _interopRequireDefault(require("webpack-node-externals"));

var _babelPluginTransformImportInline = _interopRequireDefault(require("babel-plugin-transform-import-inline"));

var _attach_webpack_configs_client_entries = _interopRequireDefault(require("./attach_webpack_configs_client_entries"));

var _get_modules_dirs = _interopRequireDefault(require("./get_modules_dirs"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const getWebpackCommonConfigs = ({
  resolveConfig,
  alias,
  nodeModulesByAssembly
}) => {
  const {
    target: targetMode,
    externalDependencies = []
  } = resolveConfig;

  if (targetMode == null) {
    throw new TypeError(`Unknown "target"`);
  }

  const distDir = _path.default.resolve(process.cwd(), resolveConfig.distDir);

  const packageJson = `common/${targetMode}-entry/package.json`;

  if (!nodeModulesByAssembly.has(packageJson)) {
    nodeModulesByAssembly.set(packageJson, new Set());
  }

  const packageJsonWriter = (context, request, callback) => {
    if (request[0] !== '/' && request[0] !== '.') {
      const packageName = request.split('/').slice(0, request[0] === '@' ? 2 : 1).join('/');
      let isExternalDependency = false;

      for (const externalDependency of externalDependencies) {
        isExternalDependency = isExternalDependency || packageName.includes(externalDependency);

        if (isExternalDependency) {
          break;
        }
      }

      if (!isExternalDependency) {
        nodeModulesByAssembly.get(packageJson).add(packageName);
      }
    }

    callback();
  };

  const baseCommonConfig = {
    context: _path.default.resolve(process.cwd()),
    mode: resolveConfig.mode,
    performance: false,
    devtool: 'source-map',
    target: 'node',
    node: {
      __dirname: true,
      __filename: true
    },
    resolve: {
      modules: (0, _get_modules_dirs.default)(),
      extensions: ['.webpack.js', '.js', '.json', '.wasm'],
      alias
    },
    output: {
      path: distDir,
      filename: '[name]',
      devtoolModuleFilenameTemplate: '[namespace][resource-path]',
      devtoolFallbackModuleFilenameTemplate: '[namespace][resource-path]?[hash]'
    },
    module: {
      rules: [{
        test: Object.values(alias),
        use: [{
          loader: require.resolve('babel-loader'),
          options: {
            cacheDirectory: true,
            babelrc: false,
            presets: [['@babel/preset-env', {
              targets: {
                node: '14.17.0'
              },
              shippedProposals: true
            }]],
            plugins: ['@babel/plugin-proposal-class-properties', '@babel/plugin-proposal-export-default-from', '@babel/plugin-proposal-export-namespace-from', ['@babel/plugin-transform-runtime', {
              corejs: false,
              helpers: false,
              regenerator: false,
              useESModules: false
            }]]
          }
        }, {
          loader: require.resolve('./val_query_loader'),
          options: {
            resolveConfig,
            isClient: false
          }
        }]
      }, {
        test: /\.js$/,
        use: {
          loader: require.resolve('babel-loader'),
          options: {
            cacheDirectory: true
          }
        },
        exclude: [/node_modules/, ...(0, _get_modules_dirs.default)({
          isAbsolutePath: true
        }), _path.default.resolve(__dirname, '../lib'), _path.default.resolve(__dirname, '../es')]
      }]
    },
    externals: [packageJsonWriter, ...(0, _get_modules_dirs.default)().map(modulesDir => (0, _webpackNodeExternals.default)({
      modulesDir,
      allowlist: [/@resolve-js\/runtime-base/]
    }))],
    plugins: []
  };
  const commonConfigs = [{ ...baseCommonConfig,
    name: `Server ${targetMode} assemblies`,
    entry: {
      [`common/${targetMode}-entry/${targetMode}-entry.js`]: _path.default.resolve(__dirname, `./alias/$resolve.serverAssemblies.js`)
    },
    output: { ...baseCommonConfig.output,
      libraryTarget: 'commonjs-module'
    },
    plugins: targetMode === 'cloud' ? [_babelPluginTransformImportInline.default] : []
  }, { ...baseCommonConfig,
    name: `Shared server ESM chunks`,
    entry: {
      'common/shared/server-imports.js': _path.default.resolve(__dirname, './alias/$resolve.serverImports.js'),
      'common/shared/server-constants.js': _path.default.resolve(__dirname, './alias/$resolve.constants.js'),
      'common/shared/server-seed-client-envs.js': _path.default.resolve(__dirname, './alias/$resolve.seedClientEnvs.js')
    },
    output: { ...baseCommonConfig.output,
      libraryTarget: 'var',
      library: '__RESOLVE_ENTRY__'
    },
    plugins: [...baseCommonConfig.plugins, new _esmWebpackPlugin.default()]
  }];
  (0, _attach_webpack_configs_client_entries.default)(resolveConfig, baseCommonConfig, commonConfigs, false);
  return commonConfigs;
};

var _default = getWebpackCommonConfigs;
exports.default = _default;
//# sourceMappingURL=get_webpack_common_configs.js.map